*;
*  TO DO: 
*
*  Lines 40 and 86: Specify the attribute to center the text 
*    of the data cells.
*;

ods Excel file="&SAMPDIR\LabResults.xlsx" style=HTMLBlue;

* Option that affects all worksheets;

ods Excel options(embedded_titles='yes');

* First worksheet;

ods Excel options(sheet_name='Female - Plot');

title1 'Change in Cholesterol from Baseline for Females - Xanomeline High Dose';
title2 'Shaded area indicates normal range';

proc sgplot data=sample.baseline_visit5 
            sganno=sample.f_cholesterol_anno
            noautolegend;
  where (sex eq 'F' and lbtest eq 'CHOLESTEROL');
  scatter x=visit5_lbstresn y=baseline_lbstresn;
  xaxis values=(4 to 8 by 1) minor minorcount=4;
  yaxis values=(4 to 8 by 1) minor minorcount=4;
  lineparm x=4 y=4 slope=1;
  label visit5_lbstresn   = 'Cholesterol at Visit 5 (mmol/L)'
        baseline_lbstresn = 'Cholesterol Baseline (mmol/L)';
run; quit;

* Second worksheet;

ods Excel options(sheet_name='Female - Report');

title2;

proc report data=sample.baseline_visit5 nowd split='*'
            style(column)=[just=center];
  where (sex eq 'F' and lbtest eq 'CHOLESTEROL');
  column usubjid  age  baseline_lbstresn  baseline_lbstresu 
         visit5_lbstresn  visit5_lbstresu  change 
         baseline_lbdtc  visit5_lbdtc;
  define usubjid            / order     'Subject*Identifier';
  define age                / display   '*Age';
  define baseline_lbstresn  / display   'Baseline*Result' format=5.2;
  define baseline_lbstresu  / display   'Unit';
  define visit5_lbstresn    / display   'Visit 5*Result' format=5.2;
  define visit5_lbstresu    / display   'Unit';
  define change             / computed  'Change from*Baseline';
  define baseline_lbdtc     / display   'Baseline Date/Time of*Specimen Collection';
  define visit5_lbdtc       / display   'Visit 5 Date/Time of*Specimen Collection'; 
  
  compute change / character length=1;
    * Placeholder for change from baseline indicator;
  endcomp;
run; quit;

* Third worksheet;

ods Excel options(sheet_name='Male - Plot');

title1 'Change in Cholesterol from Baseline for Males - Xanomeline High Dose';
title2 'Shaded area indicates normal range';

proc sgplot data=sample.baseline_visit5 
            sganno=sample.m_cholesterol_anno
            noautolegend;
  where (sex eq 'M' and lbtest eq 'CHOLESTEROL');
  scatter x=visit5_lbstresn y=baseline_lbstresn;
  xaxis values=(3 to 9 by 1) minorcount=4;
  yaxis values=(3 to 9 by 1) minorcount=4;
  lineparm x=3 y=3 slope=1;
  label visit5_lbstresn   = 'Cholesterol at Visit 5 (mmol/L)'
        baseline_lbstresn = 'Cholesterol Baseline (mmol/L)';
run; quit;

* Fourth worksheet;

ods Excel options(sheet_name='Male - Report');

title2;

proc report data=sample.baseline_visit5 nowd split='*'
            style(column)=[just=center];
  where (sex eq 'M' and lbtest eq 'CHOLESTEROL');
  column usubjid  age  baseline_lbstresn  baseline_lbstresu 
         visit5_lbstresn  visit5_lbstresu  change 
         baseline_lbdtc  visit5_lbdtc;
  define usubjid            / order     'Subject*Identifier';
  define age                / display   '*Age';
  define baseline_lbstresn  / display   'Baseline*Result' format=5.2;
  define baseline_lbstresu  / display   'Unit';
  define visit5_lbstresn    / display   'Visit 5*Result' format=5.2;
  define visit5_lbstresu    / display   'Unit';
  define change             / computed  'Change from*Baseline';
  define baseline_lbdtc     / display   'Baseline Date/Time of*Specimen Collection';
  define visit5_lbdtc       / display   'Visit 5 Date/Time of*Specimen Collection'; 
  
  compute change / character length=1;
    * Placeholder for change from baseline indicator;
  endcomp;
run; quit;

ods Excel close;

;*';*";*/;quit;run;
* Reference for code above: http://tinyurl.com/mjde9fc ;